==> jc-1.4.0.tar.gz: javax/print/attribute/URISyntax.h <==
// public abstract class javax.print.attribute.URISyntax

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bc4a0dc2546ead9f javax_print_attribute_URISyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_URISyntax_H_
#define _JC_javax_print_attribute_URISyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URI$object;

// Typedefs
typedef struct _jc_javax_print_attribute_URISyntax$sub_refs	_jc_javax_print_attribute_URISyntax$sub_refs;
typedef struct _jc_javax_print_attribute_URISyntax$sub_nonrefs	_jc_javax_print_attribute_URISyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_URISyntax$refs	_jc_javax_print_attribute_URISyntax$refs;
typedef struct _jc_javax_print_attribute_URISyntax$nonrefs	_jc_javax_print_attribute_URISyntax$nonrefs;
typedef struct _jc_javax_print_attribute_URISyntax$object	_jc_javax_print_attribute_URISyntax$object;

typedef struct _jc_javax_print_attribute_URISyntax$fields_struct	_jc_javax_print_attribute_URISyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_URISyntax$vmethods	_jc_javax_print_attribute_URISyntax$vmethods;
typedef const struct _jc_javax_print_attribute_URISyntax$vtable	_jc_javax_print_attribute_URISyntax$vtable;
typedef const struct _jc_javax_print_attribute_URISyntax$vtype	_jc_javax_print_attribute_URISyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_URISyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_URISyntax$fields_struct _jc_javax_print_attribute_URISyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_URISyntax$method$_init$7c3d63594f030366(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *, struct _jc_java_net_URI$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_URISyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_net_URI$object *_jc_javax_print_attribute_URISyntax$method$getURI$324d11203bbcd025(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *);
extern jint _jc_javax_print_attribute_URISyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_URISyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$getURI$324d11203bbcd025;
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_URISyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_net_URI$object	*(*getURI$324d11203bbcd025)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *);
};

// Vtable
struct _jc_javax_print_attribute_URISyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_URISyntax$vmethods	javax_print_attribute_URISyntax;
};

// Vtype
struct _jc_javax_print_attribute_URISyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_URISyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_URISyntax$sub_refs {
	struct _jc_java_net_URI$object	*uri;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_URISyntax$refs {
    _jc_javax_print_attribute_URISyntax$sub_refs	javax_print_attribute_URISyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_URISyntax$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_URISyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_URISyntax$sub_nonrefs	javax_print_attribute_URISyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_URISyntax$object {
	_jc_javax_print_attribute_URISyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_URISyntax$vtype	*vtype;
	_jc_javax_print_attribute_URISyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_URISyntax$vtype _jc_javax_print_attribute_URISyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_URISyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_URISyntax$class_object;

#endif	/* _JC_javax_print_attribute_URISyntax_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/URISyntax.h <==
// public abstract class javax.print.attribute.URISyntax

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc4a0dc2546ead9f javax_print_attribute_URISyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_URISyntax_H_
#define _JC_javax_print_attribute_URISyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URI$object;

// Typedefs
typedef struct _jc_javax_print_attribute_URISyntax$sub_refs	_jc_javax_print_attribute_URISyntax$sub_refs;
typedef struct _jc_javax_print_attribute_URISyntax$sub_nonrefs	_jc_javax_print_attribute_URISyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_URISyntax$refs	_jc_javax_print_attribute_URISyntax$refs;
typedef struct _jc_javax_print_attribute_URISyntax$nonrefs	_jc_javax_print_attribute_URISyntax$nonrefs;
typedef struct _jc_javax_print_attribute_URISyntax$object	_jc_javax_print_attribute_URISyntax$object;

typedef struct _jc_javax_print_attribute_URISyntax$fields_struct	_jc_javax_print_attribute_URISyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_URISyntax$vmethods	_jc_javax_print_attribute_URISyntax$vmethods;
typedef const struct _jc_javax_print_attribute_URISyntax$vtable	_jc_javax_print_attribute_URISyntax$vtable;
typedef const struct _jc_javax_print_attribute_URISyntax$vtype	_jc_javax_print_attribute_URISyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_URISyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_URISyntax$fields_struct _jc_javax_print_attribute_URISyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_URISyntax$method$_init$7c3d63594f030366(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *, struct _jc_java_net_URI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_URISyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URI$object *_jc_javax_print_attribute_URISyntax$method$getURI$324d11203bbcd025(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_URISyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_URISyntax$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$getURI$324d11203bbcd025;
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_print_attribute_URISyntax$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_javax_print_attribute_URISyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URI$object	*(*getURI$324d11203bbcd025)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_print_attribute_URISyntax$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_URISyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_URISyntax$vmethods	javax_print_attribute_URISyntax;
};

// Vtype
struct _jc_javax_print_attribute_URISyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_URISyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_URISyntax$sub_refs {
	struct _jc_java_net_URI$object	*uri;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_URISyntax$refs {
    _jc_javax_print_attribute_URISyntax$sub_refs	javax_print_attribute_URISyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_URISyntax$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_URISyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_URISyntax$sub_nonrefs	javax_print_attribute_URISyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_URISyntax$object {
	_jc_javax_print_attribute_URISyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_URISyntax$vtype	*vtype;
	_jc_javax_print_attribute_URISyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_URISyntax$vtype _jc_javax_print_attribute_URISyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_URISyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_URISyntax$class_object;

#endif	/* _JC_javax_print_attribute_URISyntax_H_ */
